## ROADMAP

To do list:

- [x] Run as `abyz -s code.abyz`
- [x] PyPI registry
- [x] Check that no valid symbols are in .abyz files (use e.g. ascii_letters)
- [ ] More complex examples
- [ ] Allow list comprehensions
